@@ -1,15 +1,14 @@
 import clickhouse_connect
 import uuid
 from rova_client.utils import SessionTracker, TraceTracker, DateTracker, simplify_dict, reverse_simplify_dict, order_by
-from typing import List, Dict
-from functools import reduce
+from typing import List, Dict, Any
 from itertools import chain
 from datetime import datetime
 
 
 class Rova:
 
-    def __init__(self, auth, timeout=1440):
+    def __init__(self, auth: str, timeout: int = 1440):
         
         self.accounts = ['buster_dev', 'rova_dev', 'danswer_dev']
 
@@ -31,15 +30,15 @@ class Rova:
         self.date_client = DateTracker()
         self.user_id = str(uuid.uuid4()) # not used if user_id is provided
     
-    def get_cols(self, auth, table):
+    def get_cols(self, auth: str, table: str) -> set[Any]:
         sql = "DESCRIBE TABLE {}.{}".format(auth, table)
         cols = set([name[0] for name in self.client.query(sql).result_rows])
         return cols
 
-    def check_auth(self, auth):
+    def check_auth(self, auth: str) -> bool:
         return (auth in self.accounts)
 
-    def error_check(self, values, columns):
+    def error_check(self, values: List[List[Any | None]], columns: List[str]) -> int:
         required_keys = {'event_name', 'event_type'}
         if(len(values) <= 0):
             raise ValueError("No data provided!")
@@ -48,16 +47,17 @@ class Rova:
             raise ValueError(f"Missing required data: {missing_keys}")
         return 0
     
-    def format_to_rova(self, obj):
+    def format_to_rova(self, obj: Dict) -> tuple[Dict, int]:
         args = simplify_dict(obj)
     
         if('timestamp' not in args):
             args['timestamp'] = self.date_client.get_timestamp()
         elif(isinstance(args['timestamp'], str)):
             args['timestamp'] = datetime.strptime(args['timestamp'], "%Y-%m-%d %H:%M:%S")
+        if('user_id' not in args or args['user_id'] is None):
+            args['user_id'] = self.user_id
         args['session_id'] = self.session_client.get_session_id(args['user_id'], args['timestamp'])
         args['distinct_id'] = uuid.uuid4()
-        args['user_id'] = args['user_id'] if args['user_id'] else self.user_id
         if(args['event_type']=='llm'):
             args['trace_id'] = self.trace_client.get_trace_id(args['user_id'], args['session_id'], 'llm')
             self.trace_client.set_last_event_type('llm')
@@ -65,8 +65,11 @@ class Rova:
         elif(args['event_type']=='product'):   
             self.trace_client.set_last_event_type('product')
             return (args, 0)
+        else:
+            # should never get here
+            return (args, -1)
     
-    def capture_handler(self, events_list, flag):
+    def capture_handler(self, events_list: List[Dict], flag: int) -> int:
 
         column_names_set = set(chain.from_iterable(map(dict.keys, events_list)))
         target_set = self.llm_cols if flag else self.product_cols
@@ -87,7 +90,7 @@ class Rova:
             print(e)
             return -1
 
-    def capture(self, args):
+    def capture(self, args: List[Dict]) -> int:
 
         sorted_data = order_by(args)
         data = [self.format_to_rova(obj) for obj in sorted_data]
