@@ -42,10 +42,10 @@ class TraceTracker():
         self.generator = UniqueIDGenerator()
         self.last_event_type = ""
 
-    def set_last_event_type(self, event_type):
+    def set_last_event_type(self, event_type: str):
       self.last_event_type = event_type
 
-    def get_trace_id(self, user_id, session_id, src):
+    def get_trace_id(self, user_id: str, session_id: int, src: str) -> int:
             
         if((user_id not in self.last_trace_ids) or (session_id not in self.trace_to_sessions.values()) or (self.last_event_type == 'product')):
             
@@ -66,9 +66,9 @@ class TraceTracker():
 
     
 class SessionTracker:
-    def __init__(self, timeout):
-        self.last_times = dict()
-        self.last_session_ids = dict()
+    def __init__(self, timeout: int):
+        self.last_times: Dict[str, datetime] = dict()
+        self.last_session_ids: Dict[str, int] = dict()
         self.timeout = timedelta(seconds=timeout)
         self.generator = UniqueIDGenerator()
     
@@ -91,14 +91,14 @@ class SessionTracker:
             return self.last_session_ids[user_id]
 
     
-def simplify_dict(d):
+def simplify_dict(d: Dict) -> Dict:
     """Simplify the dictionary by merging 'properties' into the parent dictionary."""
     simplified = d.copy()  # Make a shallow copy to avoid modifying the original
     properties = simplified.pop('properties', {})  # Remove 'properties' and save its value
     simplified.update(properties)  # Merge properties into the simplified dict
     return simplified
 
-def reverse_simplify_dict(d):
+def reverse_simplify_dict(d: Dict) -> Dict:
     """Reverse the simplification, nesting non-event_name keys under 'properties'."""
     # Extract the event_name and remove it from the original dict for a moment
     event_name = d.pop('event_name', None)
@@ -108,7 +108,7 @@ def reverse_simplify_dict(d):
     # Reconstruct the dictionary with properties nested
     return {'event_name': event_name, 'event_type':event_type, 'properties': properties}
 
-def order_by(data):
+def order_by(data: List[Dict]) -> List[Dict]:
     if('timestamp' in data[0]['properties']):
         sorted_data = sorted(data, key=lambda x: x['properties']["timestamp"])
     else:
